/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997-2004 Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    slouken@libsdl.org
*/

#ifndef _SDL_direct3dvideo_h
#define _SDL_direct3dvideo_h

#include "SDL_direct3dcommon.h"

/* Private display data */
struct SDL_PrivateVideoData {
	IDirect3D9 * __d3d9_object;
	D3DPRESENT_PARAMETERS __d3d_presentation_parameters;
	IDirect3DDevice9 * __d3d9_device;
	D3DCAPS9 __d3d9_device_caps;

#define NUM_MODELISTS	4		/* 8, 16, 24, and 32 bits-per-pixel */
	int SDL_nummodes[NUM_MODELISTS];
	SDL_Rect **SDL_modelist[NUM_MODELISTS];
	int SDL_modeindex[NUM_MODELISTS];
};

/* Macros for display data fields */
#define d3d9_object		(this->hidden->__d3d9_object)
#define d3d_presentation_parameters	(this->hidden->__d3d_presentation_parameters)
#define d3d9_device		(this->hidden->__d3d9_device)
#define d3d9_device_caps (this->hidden->__d3d9_device_caps)
#define SDL_nummodes	(this->hidden->SDL_nummodes)
#define SDL_modelist	(this->hidden->SDL_modelist)
#define SDL_modeindex	(this->hidden->SDL_modeindex)

/* Private surface data */
struct private_hwdata {
	int flags;
	SDLD3D_BlendMode blend_mode;

	IDirect3DSurface9 *surface;

	struct TextureGrid *texture_grid;
	SDL_Surface *surface_to_upload;
	Uint16 saved_pitch;
	int saved_offset;
};

/* Macro for accessing private surface data */
#define D3DPDATA(SURFACE) ((struct SDL_PrivateSurfaceData *)(SURFACE))

/* Surface data flags */
#define D3DSURFACEFLAG_IS_DISPLAY		(1 << 0)
#define D3DSURFACEFLAG_LOCKED			(1 << 1)

/* Direct3D Vertex structure */
struct textured_vertex {
	float x, y, z, rhw;  /* The transformed(screen space) position for the vertex. */
	DWORD diffuse;
	float tu,tv;         /* Texture coordinates */
};

/* Define the SDL video driver structure */
#ifndef _THIS
#define _THIS	SDL_VideoDevice *_this
#endif

#endif
